#include <Rcpp.h>
#ifndef MEDIAN1
#define MEDIAN1

int medianCpp(double x);

#endif
